Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Elemental MediaConnect.

Actions, resources, and condition keys for AWS Elemental MediaConnect - Service Authorization Reference

# Actions, resources, and condition keys for AWS Elemental MediaConnect

AWS Elemental MediaConnect (service prefix: `mediaconnect` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Elemental MediaConnect
- Resource types defined by AWS Elemental MediaConnect
- Condition keys for AWS Elemental MediaConnect

## Actions defined by AWS Elemental MediaConnect

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddBridgeOutputs | Grants permission to add outputs to an existing bridge | Write | Bridge* |  |
AddBridgeSources | Grants permission to add sources to an existing bridge | Write | Bridge* |  |
AddFlowMediaStreams | Grants permission to add media streams to any flow | Write |  |  |
AddFlowOutputs | Grants permission to add outputs to any flow | Write |  |  |
AddFlowSources | Grants permission to add sources to any flow | Write |  |  |
AddFlowVpcInterfaces | Grants permission to add VPC interfaces to any flow | Write |  |  |
CreateBridge | Grants permission to create bridges | Write | Bridge* |  |
CreateFlow | Grants permission to create flows | Write |  |  |
CreateGateway | Grants permission to create gateways | Write | Gateway* |  |
DeleteBridge | Grants permission to delete bridges | Write | Bridge* |  |
DeleteFlow | Grants permission to delete flows | Write |  |  |
DeleteGateway | Grants permission to delete gateways | Write | Gateway* |  |
DeregisterGatewayInstance | Grants permission to deregister gateway instance | Write | GatewayInstance* |  |
DescribeBridge | Grants permission to display the details of a bridge | Read | Bridge* |  |
DescribeFlow | Grants permission to display the details of a flow including the flow ARN, name, and Availability Zone, as well as details about the source, outputs, and entitlements | Read |  |  |
DescribeGateway | Grants permission to display the details of a gateway including the gateway ARN, name, and CIDR blocks, as well as details about the networks | Read | Gateway* |  |
DescribeGatewayInstance | Grants permission to display the details of a gateway instance | Read | GatewayInstance* |  |
DescribeOffering | Grants permission to display the details of an offering | Read |  |  |
DescribeReservation | Grants permission to display the details of a reservation | Read |  |  |
DiscoverGatewayPollEndpoint | Grants permission to discover gateway poll endpoint | Write |  |  |
GrantFlowEntitlements | Grants permission to grant entitlements on any flow | Write |  |  |
ListBridges | Grants permission to display a list of bridges that are associated with this account and an optionally specified Arn | List | Bridge* |  |
ListEntitlements | Grants permission to display a list of all entitlements that have been granted to the account | List |  |  |
ListFlows | Grants permission to display a list of flows that are associated with this account | List |  |  |
ListGatewayInstances | Grants permission to display a list of instances that are associated with this gateway | List | GatewayInstance* |  |
ListGateways | Grants permission to display a list of gateways that are associated with this account | List |  |  |
ListOfferings | Grants permission to display a list of all offerings that are available to the account in the current AWS Region | List |  |  |
ListReservations | Grants permission to display a list of all reservations that have been purchased by the account in the current AWS Region | List |  |  |
ListTagsForResource | Grants permission to display a list of all tags associated with a resource | Read |  |  |
PollGateway | Grants permission to poll gateway | Write |  |  |
PurchaseOffering | Grants permission to purchase an offering | Write |  |  |
RemoveBridgeOutput | Grants permission to remove an output of an existing bridge | Write | Bridge* |  |
RemoveBridgeSource | Grants permission to remove a source of an existing bridge | Write | Bridge* |  |
RemoveFlowMediaStream | Grants permission to remove media streams from any flow | Write |  |  |
RemoveFlowOutput | Grants permission to remove outputs from any flow | Write |  |  |
RemoveFlowSource | Grants permission to remove sources from any flow | Write |  |  |
RemoveFlowVpcInterface | Grants permission to remove VPC interfaces from any flow | Write |  |  |
RevokeFlowEntitlement | Grants permission to revoke entitlements on any flow | Write |  |  |
StartFlow | Grants permission to start flows | Write |  |  |
StopFlow | Grants permission to stop flows | Write |  |  |
SubmitGatewayStateChange | Grants permission to submit gateway state change | Write |  |  |
TagResource | Grants permission to associate tags with resources | Tagging |  |  |
UntagResource | Grants permission to remove tags from resources | Tagging |  |  |
UpdateBridge | Grants permission to update bridges | Write | Bridge* |  |
UpdateBridgeOutput | Grants permission to update an output of an existing bridge | Write | Bridge* |  |
UpdateBridgeSource | Grants permission to update a source of an existing bridge | Write | Bridge* |  |
UpdateBridgeState | Grants permission to update the state of an existing bridge | Write | Bridge* |  |
UpdateFlow | Grants permission to update flows | Write |  |  |
UpdateFlowEntitlement | Grants permission to update entitlements on any flow | Write |  |  |
UpdateFlowMediaStream | Grants permission to update media streams on any flow | Write |  |  |
UpdateFlowOutput | Grants permission to update outputs on any flow | Write |  |  |
UpdateFlowSource | Grants permission to update the source of any flow | Write |  |  |
UpdateGatewayInstance | Grants permission to update the configuration of an existing Gateway Instance | Write | GatewayInstance* |  |

## Resource types defined by AWS Elemental MediaConnect

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Entitlement | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:entitlement:$ { FlowId}:$ { EntitlementName}` |
Flow | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:flow:$ { FlowId}:$ { FlowName}` |
Output | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:output:$ { OutputId}:$ { OutputName}` |
Source | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:source:$ { SourceId}:$ { SourceName}` |
Gateway | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:gateway:$ { GatewayId}:$ { GatewayName}` |
Bridge | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:bridge:$ { FlowId}:$ { FlowName}` |
GatewayInstance | `arn:$ { Partition}:mediaconnect:$ { Region}:$ { Account}:gateway:$ { GatewayId}:$ { GatewayName}:instance:$ { InstanceId}` |

## Condition keys for AWS Elemental MediaConnect

MediaConnect has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.